==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/types/IntEntry.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
namespace com.db4o.test.types {

   public class IntEntry: Entry {
      
      public IntEntry() : base() {
      }
      
      public override Entry firstElement() {
         return new Entry(System.Convert.ToInt32(101), "firstvalue");
      }
      
      public override Entry lastElement() {
         return new Entry(System.Convert.ToInt32(9999999), new ObjectSimplePublic("lastValue"));
      }
      
      public override Entry noElement() {
         return new Entry(System.Convert.ToInt32(-99999), "babe");
      }
      
      public override Entry[] test(int ver) {
         if (ver == 1) {
            return new Entry[]{firstElement(), new Entry(System.Convert.ToInt32(111), new ObjectSimplePublic("111")), new Entry(System.Convert.ToInt32(9999111), System.Convert.ToDouble((double)0.4566)), lastElement()};
         }
         return new Entry[]{new Entry(System.Convert.ToInt32(222), new ObjectSimplePublic("111")), new Entry(System.Convert.ToInt32(333), "TrippleThree"), new Entry(System.Convert.ToInt32(4444), new ObjectSimplePublic("4444"))};
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/types/IntEntry.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
namespace com.db4o.test.types {

   public class IntEntry: Entry {
      
      public IntEntry() : base() {
      }
      
      public override Entry FirstElement() {
         return new Entry(System.Convert.ToInt32(101), "firstvalue");
      }
      
      public override Entry LastElement() {
         return new Entry(System.Convert.ToInt32(9999999), new ObjectSimplePublic("lastValue"));
      }
      
      public override Entry NoElement() {
         return new Entry(System.Convert.ToInt32(-99999), "babe");
      }
      
      public override Entry[] Test(int ver) {
         if (ver == 1) {
            return new Entry[]{FirstElement(), new Entry(System.Convert.ToInt32(111), new ObjectSimplePublic("111")), new Entry(System.Convert.ToInt32(9999111), System.Convert.ToDouble((double)0.4566)), LastElement()};
         }
         return new Entry[]{new Entry(System.Convert.ToInt32(222), new ObjectSimplePublic("111")), new Entry(System.Convert.ToInt32(333), "TrippleThree"), new Entry(System.Convert.ToInt32(4444), new ObjectSimplePublic("4444"))};
      }
   }
}
